import { SignatureGenerator } from "./algorithm";
import { DecodedMessage } from "./signature-format";
import { ShazamRoot } from "./types";
export declare class Endpoint {
    timezone: string;
    static SCHEME: string;
    static HOSTNAME: string;
    constructor(timezone: string);
    url(): string;
    params(): {
        sync: string;
        webv3: string;
        sampling: string;
        connected: string;
        shazamapiversion: string;
        sharehub: string;
        hubv5minorversion: string;
        hidelb: string;
        video: string;
    };
    headers(): {
        "X-Shazam-Platform": string;
        "X-Shazam-AppVersion": string;
        Accept: string;
        "Content-Type": string;
        "Accept-Encoding": string;
        "Accept-Language": string;
        "User-Agent": string;
    };
    sendRecognizeRequest(url: string, body: string): Promise<any>;
    formatAndSendRecognizeRequest(signature: DecodedMessage): Promise<ShazamRoot | null>;
}
export declare class Shazam {
    static MAX_TIME_SCEONDS: number;
    endpoint: Endpoint;
    constructor(timeZone?: string);
    recognizeSong(samples: number[], callback?: ((state: "generating" | "transmitting") => void)): Promise<{
        title: string;
        artist: string;
        album: string | undefined;
        year: string | undefined;
    } | null>;
    fullRecognizeSong(samples: number[], callback?: ((state: "generating" | "transmitting") => void)): Promise<ShazamRoot | null>;
    createSignatureGenerator(samples: number[]): SignatureGenerator;
}
